uim.codec.parser API documentation
Description: Parser This package contains different parsers for ink formats: …

# Module `uim.codec.parser`

# Parser

This package contains different parsers for ink formats:

- Universal Ink Model (v3.0.0 and v3.1.0)
- Wacom Ink Layer Language (WILL)

Expand source code

    # -*- coding: utf-8 -*-
    """
    Parser
    =======
    This package contains different parsers for ink formats:

    - Universal Ink Model (v3.0.0 and v3.1.0)
    - Wacom Ink Layer Language (WILL)

    """
    __all__ = ['decoder', 'uim', 'will']

    from uim.codec.parser import will
    from uim.codec.parser import uim
    from uim.codec.parser import decoder

## Sub-modules

`uim.codec.parser.base`
`uim.codec.parser.decoder`

  Decoder classes

  This package contains all decoders for the different versions of the Universal Ink Model: …

`uim.codec.parser.uim`
`uim.codec.parser.will`